import PdfJsLib from 'pdfjs-dist';
import React, { useState, useEffect, useRef, useMemo } from 'react';

var Pdf = function Pdf(_ref) {
  var file = _ref.file,
      onDocumentComplete = _ref.onDocumentComplete;

  var canvasEl = useRef();

  var _usePdf = usePdf({ canvasEl: canvasEl, file: file }),
      numPages = _usePdf[0];

  useEffect(function () {
    onDocumentComplete(numPages);
  }, [numPages]);

  return React.createElement('canvas', { ref: canvasEl });
};

Pdf.defaultProps = {
  onDocumentComplete: function onDocumentComplete() {}
};

export var usePdf = function usePdf(_ref2) {
  var canvasEl = _ref2.canvasEl,
      file = _ref2.file,
      _ref2$scale = _ref2.scale,
      scale = _ref2$scale === undefined ? 1 : _ref2$scale,
      _ref2$rotate = _ref2.rotate,
      rotate = _ref2$rotate === undefined ? 0 : _ref2$rotate,
      _ref2$page = _ref2.page,
      page = _ref2$page === undefined ? 1 : _ref2$page,
      _ref2$cMapUrl = _ref2.cMapUrl,
      cMapUrl = _ref2$cMapUrl === undefined ? '../node_modules/pdfjs-dist/cmaps/' : _ref2$cMapUrl,
      _ref2$cMapPacked = _ref2.cMapPacked,
      cMapPacked = _ref2$cMapPacked === undefined ? false : _ref2$cMapPacked,
      _ref2$workerSrc = _ref2.workerSrc,
      workerSrc = _ref2$workerSrc === undefined ? '//cdnjs.cloudflare.com/ajax/libs/pdf.js/2.1.266/pdf.worker.js' : _ref2$workerSrc;

  var _useState = useState(null),
      pdf = _useState[0],
      setPdf = _useState[1];

  useEffect(function () {
    PdfJsLib.GlobalWorkerOptions.workerSrc = workerSrc;
  }, []);

  useEffect(function () {
    PdfJsLib.getDocument({ url: file, cMapUrl: cMapUrl, cMapPacked: cMapPacked }).promise.then(setPdf);
  }, [file, cMapUrl, cMapPacked]);

  // handle changes
  useEffect(function () {
    if (pdf) {
      pdf.getPage(page).then(function (p) {
        return drawPDF(p);
      });
    }
  }, [pdf, page, scale, rotate, canvasEl]);

  // draw a page of the pdf
  var drawPDF = function drawPDF(page) {
    // Because this page's rotation option overwrites pdf default rotation value,
    // calculating page rotation option value from pdf default and this component prop rotate.
    var rotation = rotate === 0 ? page.rotate : page.rotate + rotate;
    var viewport = page.getViewport({ scale: scale, rotation: rotation });
    var canvas = canvasEl.current;
    var canvasContext = canvas.getContext('2d');
    canvas.height = viewport.height;
    canvas.width = viewport.width;
    var renderContext = {
      canvasContext: canvasContext,
      viewport: viewport
    };
    page.render(renderContext);
  };

  var loading = useMemo(function () {
    return !pdf;
  }, [pdf]);
  var numPages = useMemo(function () {
    return pdf ? pdf._pdfInfo.numPages : null;
  }, [pdf]);

  return [loading, numPages];
};

export default Pdf;